[evolution] Bug #245723 - Show days with transparent events in italic



commit 4b312c843d99f3bf61da8f4f8e8b0b8f90edf9f2
Author: Milan Crha <mcrha redhat com>
Date:   Thu Jul 9 13:32:43 2009 +0200

    Bug #245723 - Show days with transparent events in italic
    
    Also reset the font style back to normal when done with drawing.

 widgets/misc/e-calendar-item.c |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)
---
diff --git a/widgets/misc/e-calendar-item.c b/widgets/misc/e-calendar-item.c
index 5f4b828..9c54894 100644
--- a/widgets/misc/e-calendar-item.c
+++ b/widgets/misc/e-calendar-item.c
@@ -1709,8 +1709,9 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 			break;
 	}
 
 	/* Reset pango weight */
 	pango_font_description_set_weight (font_desc, PANGO_WEIGHT_NORMAL);
+	pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
 
 	/* Reset the foreground color. */
 	gdk_gc_set_foreground (fg_gc, &style->fg[GTK_STATE_NORMAL]);
@@ -1709,8 +1709,9 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 	}
 
-	/* Reset pango weight */
+	/* Reset pango weight and style */
 	pango_font_description_set_weight (font_desc, PANGO_WEIGHT_NORMAL);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]